aboutsummaryrefslogtreecommitdiff
path: root/sys/gnu/fs/ext2fs
diff options
context:
space:
mode:
authorBruce Evans <bde@FreeBSD.org>2004-02-15 08:19:42 +0000
committerBruce Evans <bde@FreeBSD.org>2004-02-15 08:19:42 +0000
commit053791db10a6283935d7845abec310f9ff9da9f1 (patch)
tree26cd409a255e8cbbf6dac6ad566209bd863957e7 /sys/gnu/fs/ext2fs
parent175aef1cdb46c2488ccc3e9921ffb3755a8a039c (diff)
downloadsrc-053791db10a6283935d7845abec310f9ff9da9f1.tar.gz
src-053791db10a6283935d7845abec310f9ff9da9f1.zip
Fixed misspellings of "ext2_*" as "ufs_*" and " "ext2fs_*", and of
"independent" as "dependent" Fixed some other relatively minor wording and formatting errors.
Notes
Notes: svn path=/head/; revision=125843
Diffstat (limited to 'sys/gnu/fs/ext2fs')
-rw-r--r--sys/gnu/fs/ext2fs/ext2_lookup.c13
1 files changed, 6 insertions, 7 deletions
diff --git a/sys/gnu/fs/ext2fs/ext2_lookup.c b/sys/gnu/fs/ext2fs/ext2_lookup.c
index 02ee48406bd8..d1ffa284f8bc 100644
--- a/sys/gnu/fs/ext2fs/ext2_lookup.c
+++ b/sys/gnu/fs/ext2fs/ext2_lookup.c
@@ -196,15 +196,15 @@ ext2_readdir(ap)
* from ufs on-disk ones:
* - the name is not necessarily NUL-terminated.
* - the file type field always exists and always
- * follows the name length field.
+ * follows the name length field.
* - the file type is encoded in a different way.
*
* "Old" ext2fs directory entries need no special
- * conversions, since they binary compatible with
- * "new" entries having a file type of 0 (i.e.,
+ * conversions, since they are binary compatible
+ * with "new" entries having a file type of 0 (i.e.,
* EXT2_FT_UNKNOWN). Splitting the old name length
* field didn't make a mess like it did in ufs,
- * because ext2fs uses a machine-dependent disk
+ * because ext2fs uses a machine-independent disk
* layout.
*/
dstdp.d_fileno = dp->inode;
@@ -240,7 +240,7 @@ ext2_readdir(ap)
off_t off;
if (uio->uio_segflg != UIO_SYSSPACE || uio->uio_iovcnt != 1)
- panic("ext2fs_readdir: unexpected uio from NFS server");
+ panic("ext2_readdir: unexpected uio from NFS server");
MALLOC(cookies, u_long *, ncookies * sizeof(u_long), M_TEMP,
M_WAITOK);
off = startoffset;
@@ -278,7 +278,7 @@ ext2_readdir(ap)
* be "."., but the caller must check to ensure it does an vrele and vput
* instead of two vputs.
*
* Overall outline of ufs_lookup:
*
* search for name in directory, to found or notfound
* notfound:
@@ -1004,7 +1004,6 @@ ext2_dirempty(ip, parentino, cred)
struct dirtemplate dbuf;
struct ext2_dir_entry_2 *dp = (struct ext2_dir_entry_2 *)&dbuf;
int error, count, namlen;
-
#define MINDIRSIZ (sizeof (struct dirtemplate) / 2)
for (off = 0; off < ip->i_size; off += dp->rec_len) {
@@ -278,7 +278,7 @@ ext2_readdir(ap)
* instead of two vputs.
*
- * Overall outline of ufs_lookup:
+ * Overall outline of ext2_lookup:
*
* search for name in directory, to found or notfound